@@ -11,7 +11,10 @@ import uuid
 import warnings
 from typing import Any, Awaitable, Callable, Dict, List, Optional, Tuple, Type, Union
 
+import gvcode
 import shortuuid
+import vcode as mod_vcode
+from CodeConvert import CodeConvert as cc
 from redis import StrictRedis
 from redis.client import bool_ok
 from redis.exceptions import DataError, ResponseError, WatchError
@@ -21,16 +24,6 @@ from TimeConvert import TimeConvert as tc
 from .expires import BaseRedisExpires
 
 
-try:
-    import gvcode
-except ImportError:
-    pass
-try:
-    import vcode as mod_vcode
-except ImportError:
-    pass
-
-
 ResponseT = Union[Awaitable, Any]
 ResponseIntT = Union[Awaitable[int], int]
 ResponseStrT = Union[Awaitable[str], str]
@@ -49,6 +42,20 @@ KEY_PREFIX = 'r:'  # Prefix of redis-extensions used key
 WARNING_LOG = '``{0}`` used, may be very very very slow when keys\' amount very large'  # ``r.keys()`` and ``r.scan_iter()`` not support use
 
 
+POLL_QUEUE_CONTINUE_FLAG = True
+
+
+# Signal Handler
+def sigintHandler(signum, frame):
+    global POLL_QUEUE_CONTINUE_FLAG
+    POLL_QUEUE_CONTINUE_FLAG = False
+
+
+# signal.SIGKILL, `KILL -9`, unblockable
+for signum in [signal.SIGHUP, signal.SIGINT, signal.SIGTERM, signal.SIGTSTP]:
+    signal.signal(signum, sigintHandler)
+
+
 # Get the local ip
 def get_network_ip() -> str:
     try:
@@ -62,7 +69,7 @@ def get_network_ip() -> str:
     return ip
 
 
-class RedisExtensions(BaseRedisExpires, StrictRedis):
+class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
     """
     Extension of [redis-py](https://github.com/andymccurdy/redis-py)'s StrictRedis.
 
@@ -73,9 +80,8 @@ class RedisExtensions(BaseRedisExpires, StrictRedis):
         self.rate = 10000000000000  # 10 ** 13,
         self.max_timestamp = 9999999999999
         self.timezone = kwargs.pop('timezone', None)
-        self.poll_queue_continue_flag = True
         tc.__init__(timezone=self.timezone)
-        super(RedisExtensions, self).__init__(*args, **kwargs)
+        super(StrictRedisExtensions, self).__init__(*args, **kwargs)
 
     def __str(self, x: Any) -> Union[str, bytes]:
         if isinstance(x, int):
@@ -1140,7 +1146,7 @@ class RedisExtensions(BaseRedisExpires, StrictRedis):
                 logger.warning('Gvcode not found, exec gvcode_add or gvcode_refresh first')
         b64str, vcode = gvcode.get('b64str', ''), gvcode.get('vcode', '')
         self.setex(self.__gvcode_key(name), time, vcode)
-        return '{0}{1}'.format('data:image/png;base64,' if data_uri_scheme else '', b64str)
+        return '{0}{1}'.format('data:image/png;base64,' if data_uri_scheme else '', cc.Convert2Utf8(b64str))
 
     def gvcode_exists(self, name: str, code: str, ignore_blank: bool = True) -> bool:
         return (self.get(self.__gvcode_key(name)) or '').lower() == self.__final_code(code, ignore_blank=ignore_blank)
@@ -1201,10 +1207,6 @@ class RedisExtensions(BaseRedisExpires, StrictRedis):
         self.release_poll_queue_lock(delayed, final_logger=final_logger)
         final_logger.info('>>> Release item lock end')
 
-    # Signal Handler
-    def __signal_handler(self, signum, frame):
-        self.poll_queue_continue_flag = False
-
     def poll_queue(self, callbacks: Dict[str, Callable] = {}, delayed: str = KEY_PREFIX + 'delayed:default', enable_auto_zrem: bool = False, enable_queue: bool = False, enable_process_lock: bool = False, process_lock_key: Optional[str] = None, release_lock_when_launch: bool = True, release_lock_eth0_inet_addr: Optional[str] = None, release_lock_when_error: bool = True, delayed_logger: Optional[logging.Logger] = None, unlocked_warning_func: Optional[Callable] = None):
         """
         Consumer of delay execute.
@@ -1225,10 +1227,6 @@ class RedisExtensions(BaseRedisExpires, StrictRedis):
 
         ``release_lock_when_error`` indicates whether release lock when error or not.
         """
-        # signal.SIGKILL, `KILL -9`, unblockable
-        for signum in [signal.SIGHUP, signal.SIGINT, signal.SIGTERM, signal.SIGTSTP]:
-            signal.signal(signum, self.__signal_handler)
-
         callbacks = {k: self.__callable_func(v) for k, v in callbacks.items()}
         callbacks = {k: v for k, v in callbacks.items() if v}
 
@@ -1242,7 +1240,7 @@ class RedisExtensions(BaseRedisExpires, StrictRedis):
         self.__release_lock_when_launch(release_lock_when_launch, release_lock_eth0_inet_addr, final_process_lock_key, delayed, final_logger)
 
         process_lock = None
-        while self.poll_queue_continue_flag:
+        while POLL_QUEUE_CONTINUE_FLAG:
             if enable_process_lock:
                 # Release process lock
                 if process_lock:
@@ -1419,6 +1417,3 @@ class RedisExtensions(BaseRedisExpires, StrictRedis):
     dellpush = del_lpush = delpush = del_push = delete_lpush
     delrpush = del_rpush = delete_rpush
     delsadd = del_sadd = delete_sadd
-
-
-StrictRedisExtensions = RedisExtensions
